@@ -9,7 +9,7 @@
 #
 #
 
-from pyparsing import *
+import pyparsing as pp
 
 # sample string with enums and other stuff
 sample = """
@@ -35,19 +35,19 @@ sample = """
     """
 
 # syntax we don't want to see in the final parse tree
-LBRACE, RBRACE, EQ, COMMA = map(Suppress, "{}=,")
-_enum = Suppress("enum")
-identifier = Word(alphas, alphanums + "_")
-integer = Word(nums)
-enumValue = Group(identifier("name") + Optional(EQ + integer("value")))
-enumList = Group(enumValue + ZeroOrMore(COMMA + enumValue))
+LBRACE, RBRACE, EQ, COMMA = pp.Suppress.using_each("{}=,")
+_enum = pp.Suppress("enum")
+identifier = pp.Word(pp.alphas + "_", pp.alphanums + "_")
+integer = pp.Word(pp.nums)
+enumValue = pp.Group(identifier("name") + pp.Optional(EQ + integer("value")))
+enumList = pp.Group(enumValue + (COMMA + enumValue)[...])
 enum = _enum + identifier("enum") + LBRACE + enumList("names") + RBRACE
 
 # find instances of enums ignoring other syntax
-for item, start, stop in enum.scanString(sample):
-    id = 0
+for item, start, stop in enum.scan_string(sample):
+    idx = 0
     for entry in item.names:
         if entry.value != "":
-            id = int(entry.value)
-        print("%s_%s = %d" % (item.enum.upper(), entry.name.upper(), id))
-        id += 1
+            idx = int(entry.value)
+        print("%s_%s = %d" % (item.enum.upper(), entry.name.upper(), idx))
+        idx += 1
